@@ -11,11 +11,11 @@ class DatabaseTests(IntegrationTestCase):
         """Ensure Database can be imported from Metabase."""
         from metabase import Database
 
-        self.assertIsNotNone(Database())
+        self.assertIsNotNone(Database(_using=None))
 
     def test_list(self):
         """Ensure Database.list() returns a list of Database instances."""
-        databases = Database.list()
+        databases = Database.list(using=self.metabase)
 
         self.assertIsInstance(databases, list)
         self.assertTrue(len(databases) > 0)
@@ -23,7 +23,7 @@ class DatabaseTests(IntegrationTestCase):
 
     def test_get(self):
         """Ensure Database.get() returns a Database instance for a given ID."""
-        database = Database.get(1)
+        database = Database.get(1, using=self.metabase)
 
         self.assertIsInstance(database, Database)
         self.assertEqual(1, database.id)
@@ -36,13 +36,14 @@ class DatabaseTests(IntegrationTestCase):
             details={
                 "db": "zip:/app/metabase.jar!/sample-dataset.db;USER=GUEST;PASSWORD=guest"
             },
+            using=self.metabase,
         )
 
         self.assertIsInstance(database, Database)
         self.assertEqual("Test", database.name)
         self.assertEqual("h2", database.engine)
         self.assertIsInstance(
-            Database.get(database.id), Database
+            Database.get(database.id, using=self.metabase), Database
         )  # instance exists in Metabase
 
         # teardown
@@ -50,7 +51,7 @@ class DatabaseTests(IntegrationTestCase):
 
     def test_update(self):
         """Ensure Database.update() updates an existing Database in Metabase."""
-        database = Database.get(1)
+        database = Database.get(1, using=self.metabase)
 
         name = database.name
         database.update(name="New Name")
@@ -59,7 +60,7 @@ class DatabaseTests(IntegrationTestCase):
         self.assertEqual("New Name", database.name)
 
         # assert metabase object is mutated
-        t = Database.get(database.id)
+        t = Database.get(database.id, using=self.metabase)
         self.assertEqual("New Name", t.name)
 
         # teardown
@@ -74,6 +75,7 @@ class DatabaseTests(IntegrationTestCase):
             details={
                 "db": "zip:/app/metabase.jar!/sample-dataset.db;USER=GUEST;PASSWORD=guest"
             },
+            using=self.metabase,
         )
         self.assertIsInstance(database, Database)
 
@@ -81,11 +83,11 @@ class DatabaseTests(IntegrationTestCase):
 
         # assert metabase object is mutated
         with self.assertRaises(NotFoundError):
-            _ = Database.get(database.id)
+            _ = Database.get(database.id, using=self.metabase)
 
     def test_fields(self):
         """Ensure Database.fields() returns a list of Field instances."""
-        database = Database.get(1)
+        database = Database.get(1, using=self.metabase)
         fields = database.fields()
 
         self.assertIsInstance(fields, list)
@@ -94,7 +96,7 @@ class DatabaseTests(IntegrationTestCase):
 
     def test_idfields(self):
         """Ensure Database.idfields() returns a list of Field instances."""
-        database = Database.get(1)
+        database = Database.get(1, using=self.metabase)
         fields = database.idfields()
 
         self.assertIsInstance(fields, list)
@@ -103,7 +105,7 @@ class DatabaseTests(IntegrationTestCase):
 
     def test_schemas(self):
         """Ensure Database.schemas() returns a list of strings."""
-        database = Database.get(1)
+        database = Database.get(1, using=self.metabase)
         schemas = database.schemas()
 
         self.assertIsInstance(schemas, list)
@@ -112,7 +114,7 @@ class DatabaseTests(IntegrationTestCase):
 
     def test_tables(self):
         """Ensure Database.tables() returns a list of Table instances."""
-        database = Database.get(1)
+        database = Database.get(1, using=self.metabase)
         schema = database.schemas()[0]
         tables = database.tables(schema)
 
@@ -122,28 +124,28 @@ class DatabaseTests(IntegrationTestCase):
 
     def test_discard_values(self):
         """Ensure Database.discard_values() does not raise an error."""
-        database = Database.get(1)
+        database = Database.get(1, using=self.metabase)
         response = database.discard_values()
 
         self.assertEqual(200, response.status_code)
 
     def test_rescan_values(self):
         """Ensure Database.rescan_values() does not raise an error."""
-        database = Database.get(1)
+        database = Database.get(1, using=self.metabase)
         response = database.rescan_values()
 
         self.assertEqual(200, response.status_code)
 
     def test_sync(self):
         """Ensure Database.sync() does not raise an error."""
-        database = Database.get(1)
+        database = Database.get(1, using=self.metabase)
         response = database.sync()
 
         self.assertEqual(200, response.status_code)
 
     def test_sync_schema(self):
         """Ensure Database.sync_schema() does not raise an error."""
-        database = Database.get(1)
+        database = Database.get(1, using=self.metabase)
         response = database.sync_schema()
 
         self.assertEqual(200, response.status_code)
