@@ -7,7 +7,7 @@ from tests.helpers import IntegrationTestCase
 
 class UserTests(IntegrationTestCase):
     def tearDown(self) -> None:
-        users = User.list()
+        users = User.list(using=self.metabase)
         for user in users:
             if user.id != 1:
                 user.delete()
@@ -16,7 +16,7 @@ class UserTests(IntegrationTestCase):
         """Ensure User can be imported from Metabase."""
         from metabase import User
 
-        self.assertIsNotNone(User())
+        self.assertIsNotNone(User(_using=None))
 
     def test_get(self):
         """
@@ -29,21 +29,26 @@ class UserTests(IntegrationTestCase):
             last_name="Test",
             email=f"{randint(2, 10000)}@example.com",
             password="example123",
+            using=self.metabase,
         )
         self.assertIsInstance(user, User)
 
-        u = User.get(user.id)
+        u = User.get(user.id, using=self.metabase)
         self.assertIsInstance(u, User)
         self.assertEqual(user.id, u.id)
 
         with self.assertRaises(NotFoundError):
-            _ = User.get(12345)
+            _ = User.get(12345, using=self.metabase)
 
     def test_create(self):
         """Ensure User.create() creates a User in Metabase and returns a User instance."""
         email = f"{randint(2, 10000)}@example.com"
         user = User.create(
-            first_name="Test", last_name="Test", email=email, password="example123"
+            first_name="Test",
+            last_name="Test",
+            email=email,
+            password="example123",
+            using=self.metabase,
         )
 
         self.assertIsInstance(user, User)
@@ -59,6 +64,7 @@ class UserTests(IntegrationTestCase):
             last_name="Test",
             email=f"{randint(2, 10000)}@example.com",
             password="example123",
+            using=self.metabase,
         )
 
         self.assertIsInstance(user, User)
@@ -69,7 +75,7 @@ class UserTests(IntegrationTestCase):
         self.assertEqual("Test1", user.first_name)
 
         # assert metabase object is mutated
-        u = User.get(user.id)
+        u = User.get(user.id, using=self.metabase)
         self.assertEqual("Test1", u.first_name)
 
     def test_delete(self):
@@ -80,6 +86,7 @@ class UserTests(IntegrationTestCase):
             last_name="Test",
             email=f"{randint(2, 10000)}@example.com",
             password="example123",
+            using=self.metabase,
         )
         self.assertIsInstance(user, User)
 
@@ -87,4 +94,4 @@ class UserTests(IntegrationTestCase):
 
         # assert metabase object is mutated
         with self.assertRaises(NotFoundError):
-            _ = User.get(user.id)
+            _ = User.get(user.id, using=self.metabase)
